summaryrefslogtreecommitdiffstats
path: root/src/render/backend/entity.cpp
diff options
context:
space:
mode:
authorPaul Lemire <paul.lemire350@gmail.com>2016-02-25 19:52:03 +0100
committerPaul Lemire <paul.lemire@kdab.com>2016-03-05 10:18:05 +0000
commit34b3c898f4d7cbac46550a59bf5ac487df578188 (patch)
tree273a47e822dcf13121fcccae6cb59376fdca5ca4 /src/render/backend/entity.cpp
parente0edb256b8fa9a7f459ab20f1554b7578dcb27a2 (diff)
QBackendNode::peerUuid() renamed to peerId()
Change-Id: I72471d0b22d16bbbee33610e30a06daadffedbd9 Reviewed-by: Paul Lemire <paul.lemire@kdab.com>
Diffstat (limited to 'src/render/backend/entity.cpp')
-rw-r--r--src/render/backend/entity.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/render/backend/entity.cpp b/src/render/backend/entity.cpp
index 5a25c2157..4c2650195 100644
--- a/src/render/backend/entity.cpp
+++ b/src/render/backend/entity.cpp
@@ -90,9 +90,9 @@ void Entity::cleanup()
parentEntity->removeChildHandle(m_handle);
for (int i = 0; i < m_childrenHandles.size(); i++)
m_nodeManagers->renderNodesManager()->release(m_childrenHandles[i]);
// We need to release using peerUuid otherwise the handle will be cleared
// but would still remain in the Id to Handle table
- m_nodeManagers->worldMatrixManager()->releaseResource(peerUuid());
+ m_nodeManagers->worldMatrixManager()->releaseResource(peerId());
qCDebug(Render::RenderNodes) << Q_FUNC_INFO;
@@ -148,7 +148,7 @@ void Entity::updateFromPeer(Qt3DCore::QNode *peer)
const QNodeId parentEntityId = entityPrivate->parentEntityId();
m_objectName = peer->objectName();
- m_worldTransform = m_nodeManagers->worldMatrixManager()->getOrAcquireHandle(peerUuid());
+ m_worldTransform = m_nodeManagers->worldMatrixManager()->getOrAcquireHandle(peerId());
// TO DO: Suboptimal -> Maybe have a Hash<QComponent, QEntityList> instead
m_transformComponent = QNodeId();
@@ -160,9 +160,9 @@ void Entity::updateFromPeer(Qt3DCore::QNode *peer)
m_layerComponents.clear();
m_shaderDataComponents.clear();
m_lightComponents.clear();
- m_localBoundingVolume.reset(new Sphere(peerUuid()));
- m_worldBoundingVolume.reset(new Sphere(peerUuid()));
- m_worldBoundingVolumeWithChildren.reset(new Sphere(peerUuid()));
+ m_localBoundingVolume.reset(new Sphere(peerId()));
+ m_worldBoundingVolume.reset(new Sphere(peerId()));
+ m_worldBoundingVolumeWithChildren.reset(new Sphere(peerId()));
Q_FOREACH (QComponent *comp, entity->components())
addComponent(comp);
@@ -170,7 +170,7 @@ void Entity::updateFromPeer(Qt3DCore::QNode *peer)
if (!parentEntityId.isNull()) {
setParentHandle(m_nodeManagers->renderNodesManager()->lookupHandle(parentEntityId));
} else {
- qCDebug(Render::RenderNodes) << Q_FUNC_INFO << "No parent entity found for Entity" << peerUuid();
+ qCDebug(Render::RenderNodes) << Q_FUNC_INFO << "No parent entity found for Entity" << peerId();
}
m_enabled = entity->isEnabled();
@@ -90,9 +90,9 @@ void Entity::cleanup()
for (int i = 0; i < m_childrenHandles.size(); i++)
m_nodeManagers->renderNodesManager()->release(m_childrenHandles[i]);
- // We need to release using peerUuid otherwise the handle will be cleared
+ // We need to release using peerId otherwise the handle will be cleared
// but would still remain in the Id to Handle table